package SDL2::MetalView {
    use SDL2::Utils;
    has();

=encoding utf-8

=head1 NAME

SDL2::MetalView - A handle to a CAMetalLayer-backed NSView (OSX) or UIView
(iOS/tvOS)

=head1 SYNOPSIS

    use SDL2 qw[:all];
    # TODO: I need to whip up a quick example

=head1 DESCRIPTION


=head1 Fields


=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords

CAMetalLayer-backed NSView UIView

=end stopwords

=cut

};
1;
