
package SDL2::FPoint {
    use SDL2::Utils;
    has x => 'float', y => 'float';

=encoding utf-8

=head1 NAME

SDL2::FPoint - The Structure that Defines a Point with Floating Point Numbers

=head1 SYNOPSIS

    use SDL2 qw[:all];
    my $point = SDL2::FPoint->new( { x => 1.5, y => 1.5 } );

=head1 DESCRIPTION

SDL2::FPoint

=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords

=end stopwords

=cut

};
1
