package SDL2::MessageBoxColor {
    use SDL2::Utils;
    has
        r => 'uint8',
        g => 'uint8',
        b => 'uint8';

=encoding utf-8

=head1 NAME

SDL2::MessageBoxColor - RGB value used in message box color scheme

=head1 SYNOPSIS

    use SDL2 qw[:all];
    # TODO: I need to whip up a quick example

=head1 DESCRIPTION


=head1 Fields

=over

=item C<r>

=item C<g>

=item C<b>

=back

=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords


=end stopwords

=cut

};
1;
