package SDL2::Semaphore {

    use SDL2::Utils;
    use SDL2::Sem;
    has();

=encoding utf-8

=head1 NAME

SDL2::Semaphore - SDL semaphore structure

=head1 SYNOPSIS

    use SDL2 qw[:all];
    # TODO: I need to whip up a quick example

=head1 DESCRIPTION


=head1 Fields
 

=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords


=end stopwords

=cut

};
1;
