package SDL2::Renderer {
    use SDL2::Utils;
    has();

=encoding utf-8

=head1 NAME

SDL2::Renderer - A structure representing rendering state

=head1 SYNOPSIS

    use SDL2 qw[:all];
    # TODO

=head1 DESCRIPTION

SDL2::Renderer

=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords



=end stopwords

=cut

};
1;
