    package SDL2::Texture {
        use SDL2::Utils;
        has();

=encoding utf-8

=head1 NAME

SDL2::Texture - An efficient driver-specific representation of pixel data

=head1 SYNOPSIS

    use SDL2 qw[:all];
    # TODO

=head1 DESCRIPTION

SDL2::Texture

=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords



=end stopwords

=cut

    };
    1;
